<?php
session_start(); // start session cookies
include("../login_config.php");
require("../inc/Login.class.php");
$login = new Login; // create object login

$login->authorize(); // make user login

require_once '../heating_config.php';
require_once 'HeatMiser/Wifi.php';
include '../heating_log/external_temp.php';

try {
    // ip, pin, optional port
    $hm = new \PhilLavin\HeatMiser\Wifi($heatmiser_ip, $heatmiser_pin);
    $dcb = $hm->get_dcb();
    $hm->put_dcb($dcb);
    $dcb = $hm->get_dcb();
}
catch (\PhilLavin\HeatMiser\ConnectionFailedException $e) {
    die("Failed to connect: ".$e->getMessage()."\n");
}
catch (\Exception $e) {
    die("Exception of type ".get_class($e)." thrown. Error was: {$e->getMessage()}\n");
}

?>


<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width; initial-scale=1.0; maximum-scale=1.0;">
    <title>House Control</title>
    <link href="../css/style.css" rel="stylesheet" type="text/css" />
</head>
<body>
	<header>
        <div class="logo">
            <a href="index.php">
                House Heating System
            </a>
        </div>
    </header>    
    <div class="content">

    <article class="underline">
    	<h2>Current Status</h2>
			<p>
				<span class="a1">Temperature:</span> <span class="b1"><?php echo($dcb['internal_temperature']); ?> &deg;<?php echo($dcb['units']); ?></span><br>
				<span class="a1">Target:</span> <span class="b1"><?php echo($dcb['runmode'] == "Heating" ? $dcb['heating_target'] : $dcb['frostprotect_target']); ?> &deg;<?php echo($dcb['units']); ?></span><br>
				<span class="a1">External:</span> <span class="b1"><?php echo(get_external_temp()); ?> &deg;C</span><br>
				<span class="a1">Heating Status:</span> <span class="b1"><?php echo($dcb['heating_on'] == 1 ? "On" : "Off") ?></span><br>
				<span class="a1">Runmode:</span> <span class="b1"><?php echo($dcb['runmode']) ?></span><br>
				<span class="a1">Hold:</span> <span class="b1"><?php echo($dcb['heating_hold']) ?> mins</span><br>
				<span class="a1">Keylock:</span> <span class="b1"><?php echo($dcb['keylock'] == 1 ? "On" : "Off") ?></span><br>
				<span class="a1">Current Time:</span> <span class="b1"><?php echo($dcb['time']) ?></span><br>
				<span class="a1">Holiday:</span> <span class="b1"><?php echo($dcb['holiday_enabled'] == 1 ? $dcb['holiday'] : "Disabled") ?></span>
			</p>
    </article>


    <article class="underline">
    	<h2>Temperature Override</h2>
			<p>
				<form action="heatmiser_override.php" method="get" class="label-top">
					<?
					foreach($temperature_options as $temperature)
					{
						echo('<input type="submit" name="temp" value="'.$temperature.'" />  ');
					}
					?>
				</form>
			</p>
    </article>


    <article class="underline">
    	<h2>Temperature Hold</h2>
			<form action="heatmiser_hold.php" method="get" class="label-top">
				<p>
					<label for="time" class="inline">Duration:</label>
					<select name="time" id="select-choice">
						<?php
						for ($i=0; $i<1440; $i+=30)
						{
							if (($dcb['heating_hold'] >= $i) && ($dcb['heating_hold'] < $i + 30))
							{
								$selected = " selected";
							}
							else
							{
								$selected = "";
							}
							echo("<option value='".$i."'".$selected.">".floor($i / 60).":".str_pad(($i % 60), 2, '0', STR_PAD_LEFT)."</option>\r\n");
						}
						?>
					</select>
				</p>
				<p>
					<?
					foreach($temperature_options as $temperature)
					{
						echo('<input type="submit" name="temp" value="'.$temperature.'" />  ');
					}
					?>
				</p>
			</form>
    </article>
        
    </div>
    <footer>
		<nav class="vertical menu">
            <ul>
                <li><a href="settings.php">Settings</a></li>
                <li><a href="programming.php">Update Programming</a></li>
                <li><a href="holiday.php">Holiday</a></li>
            </ul>
        </nav> 
        <p class="copy"><a href="../">House Control</a> | <a href="index.php?action=clear_login">Logout</a></p>
    </footer>
</body>
</html>
